@@ -214,6 +214,23 @@ impl Reflection {
             .ok_or(ReflectError::UnassignedResultId(id))
     }
 
+    pub fn get_compute_group_size(&self) -> Option<(u32, u32, u32)> {
+        for inst in self.0.global_inst_iter() {
+            if inst.class.opcode == spirv::Op::ExecutionMode {
+                use rspirv::dr::Operand::{ExecutionMode, LiteralInt32};
+                if let [ExecutionMode(
+                    spirv::ExecutionMode::LocalSize | spirv::ExecutionMode::LocalSizeHint,
+                ), LiteralInt32(x), LiteralInt32(y), LiteralInt32(z)] = inst.operands[1..]
+                {
+                    return Some((x, y, z));
+                } else {
+                    // Invalid encoding? Ignoring.
+                }
+            }
+        }
+        None
+    }
+
     /// Returns the descriptor type for a given variable `type_id`
     fn get_descriptor_type_for_var(
         &self,
